#include "TkInterp.h"
 
int
main (int argc, const char **argv)
{
  id tk = [[TkInterp alloc] initWithArgc:argc argv:argv];
  
  [tk promptAndEval];
  exit(0);
}
